==> odoo_19.0.20251010.zip: odoo-19.0.post20251010/odoo/addons/website_sale/static/src/website_builder/product_image_option_plugin.js <==
import { REPLACE_MEDIA } from "@html_builder/utils/option_sequence";
import {
    REPLACE_MEDIA_SELECTOR,
    REPLACE_MEDIA_EXCLUDE,
} from "@html_builder/plugins/image/image_tool_option_plugin";
import { Plugin } from "@html_editor/plugin";
import { withSequence } from "@html_editor/utils/resource";
import { rpc } from "@web/core/network/rpc";
import { registry } from "@web/core/registry";
import { BuilderAction } from "@html_builder/core/builder_action";

const PRODUCT_IMAGE_OPTION_SELECTOR = `.o_wsale_product_images :is(${REPLACE_MEDIA_SELECTOR})`;

export class ProductImageOptionPlugin extends Plugin {
    static id = "productImageOption";
    resources = {
        builder_options: [
            withSequence(REPLACE_MEDIA, {
                template: "website_sale.ProductImageOption",
                selector: PRODUCT_IMAGE_OPTION_SELECTOR,
                exclude: REPLACE_MEDIA_EXCLUDE,
            }),
        ],
        builder_actions: {
            /*
             * Change sequence of product page images
             */
            SetPositionAction,
            /*
             * Removes the image in the back-end
             */
            RemoveMediaAction,
        },
        patch_builder_options: [
            {
                target_name: "replaceMediaOption",
                target_element: "exclude",
                method: "add",
                value: PRODUCT_IMAGE_OPTION_SELECTOR,
            },
        ],
    };
}

/*
* Change sequence of product page images
*/
export class SetPositionAction extends BuilderAction {
    static id = "setPosition";
    setup() {
        this.reload = {};
    }
    async apply({ editingElement: el, value }) {
        const params = {
            image_res_model: el.parentElement.dataset.oeModel,
            image_res_id: el.parentElement.dataset.oeId,
            move: value,
        };

        await rpc("/shop/product/resequence-image", params);
    }
}
/*
 * Removes the image in the back-end
 */
export class RemoveMediaAction extends BuilderAction {
    static id = "removeMedia";
    setup() {
        this.reload = {};
    }
    async apply({ editingElement: el }) {
        if (el.parentElement.dataset.oeModel === "product.image") {
            // Unlink the "product.image" record as it is not the main product image.
            await this.services.orm.unlink("product.image", [
                parseInt(el.parentElement.dataset.oeId),
            ]);
        }
        el.remove();
    }
}

registry.category("website-plugins").add(ProductImageOptionPlugin.id, ProductImageOptionPlugin);

==> odoo_19.0.20260126.zip: odoo-19.0.post20260126/odoo/addons/website_sale/static/src/website_builder/product_image_option_plugin.js <==
import { REPLACE_MEDIA } from "@html_builder/utils/option_sequence";
import {
    ReplaceMediaOption,
} from "@html_builder/plugins/image/replace_media_option";
import { Plugin } from "@html_editor/plugin";
import { withSequence } from "@html_editor/utils/resource";
import { rpc } from "@web/core/network/rpc";
import { registry } from "@web/core/registry";
import { BuilderAction } from "@html_builder/core/builder_action";
import { BaseOptionComponent } from "@html_builder/core/utils";


export class ProductImageOption extends BaseOptionComponent {
    static template = "website_sale.ProductImageOption";
    static selector =  `.o_wsale_product_images :is(${ReplaceMediaOption.selector})`;
    static exclude = ReplaceMediaOption.exclude;
}

export class ProductImageOptionPlugin extends Plugin {
    static id = "productImageOption";
    resources = {
        builder_options: [
            withSequence(REPLACE_MEDIA, ProductImageOption),
        ],
        builder_actions: {
            /*
             * Change sequence of product page images
             */
            SetPositionAction,
            /*
             * Removes the image in the back-end
             */
            RemoveMediaAction,
        },
        patch_builder_options: [
            {
                target_name: "replaceMediaOption",
                target_element: "exclude",
                method: "add",
                value: ProductImageOption.selector,
            },
        ],
    };
}

/*
* Change sequence of product page images
*/
export class SetPositionAction extends BuilderAction {
    static id = "setPosition";
    setup() {
        this.reload = {};
    }
    async apply({ editingElement: el, value }) {
        const params = {
            image_res_model: el.parentElement.dataset.oeModel,
            image_res_id: el.parentElement.dataset.oeId,
            move: value,
        };

        await rpc("/shop/product/resequence-image", params);
    }
}
/*
 * Removes the image in the back-end
 */
export class RemoveMediaAction extends BuilderAction {
    static id = "removeMedia";
    setup() {
        this.reload = {};
    }
    async apply({ editingElement: el }) {
        if (el.parentElement.dataset.oeModel === "product.image") {
            // Unlink the "product.image" record as it is not the main product image.
            await this.services.orm.unlink("product.image", [
                parseInt(el.parentElement.dataset.oeId),
            ]);
        }
        el.remove();
    }
}

registry.category("website-plugins").add(ProductImageOptionPlugin.id, ProductImageOptionPlugin);
